"""Visualization utilities for CPI analytics."""

from .plots import (
    DensityPlotConfig,
    HistogramPlotConfig,
    PlotReport,
    generate_density_plot,
    generate_histogram_plot,
)

__all__ = [
    "DensityPlotConfig",
    "HistogramPlotConfig",
    "PlotReport",
    "generate_density_plot",
    "generate_histogram_plot",
]
